@@ -7,6 +7,7 @@ from cone.app.interfaces import IApplicationNode
 from cone.app.interfaces import ICopySupport
 from cone.app.interfaces import IFactoryNode
 from cone.app.interfaces import ILayoutConfig
+from cone.app.interfaces import ILeafNode
 from cone.app.interfaces import IMetadata
 from cone.app.interfaces import INodeInfo
 from cone.app.interfaces import IProperties
@@ -166,6 +167,26 @@ class AppNode(Behavior):
         return info
 
 
+@implementer(ILeafNode)
+class LeafNode(AppNode):
+
+    @default
+    def __getitem__(self, name):
+        raise KeyError(name)
+
+    @default
+    def __setitem__(self, name, value):
+        raise KeyError(name)
+
+    @default
+    def __delitem__(self, name):
+        raise KeyError(name)
+
+    @default
+    def __iter__(self):
+        return iter([])
+
+
 @plumbing(
     AppNode,
     AsAttrAccess,
@@ -270,15 +291,16 @@ class NamespaceUUID(Behavior):
 class UUIDAttributeAware(UUIDAware):
     """UUIDAware deriving behavior storing the uid on node attributes.
     """
+    uuid_attribute_name = default('uuid')
 
     @property
     def uuid(self):
-        return self.attrs['uuid']
+        return self.attrs.get(self.uuid_attribute_name)
 
     @default
     @uuid.setter
     def uuid(self, value):
-        self.attrs['uuid'] = value
+        self.attrs[self.uuid_attribute_name] = value
 
 
 @implementer(IUUIDAsName)
