@@ -18,11 +18,13 @@ import venusian
 def reset_node_info_registry(fn):
     """Decorator for tests using node info registry
     """
+    node_info_registry = model._node_info_registry
     def wrapper(*a, **kw):
         try:
+            model._node_info_registry = dict()
             fn(*a, **kw)
         finally:
-            model._node_info_registry = dict()
+            model._node_info_registry = node_info_registry
     return wrapper
 
 
@@ -185,6 +187,7 @@ class Security(object):
             'ugm.groups_file': os.path.join(DATADIR, 'groups'),
             'ugm.roles_file': os.path.join(DATADIR, 'roles'),
             'ugm.datadir': os.path.join(DATADIR, 'userdata'),
+            'ugm.user_expires_attr': 'expires',
             'testing.hook_global_registry': True,
         }
         settings.update(**kw)
